==> digikam_4.4.0.orig.tar.bz2: digikam-4.4.0/extra/kipi-plugins/panorama/plugin/kipiplugin_panorama.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Panorama
Name=Panorama
Name[bg]=Панорама
Name[bs]=Panorama
Name[ca]=Panorama
Name[ca@valencia]=Panorama
Name[cs]=Panorama
Name[da]=Panorama
Name[de]=Panorama
Name[el]=Πανόραμα
Name[en_GB]=Panorama
Name[es]=Panorama
Name[et]=Panoraam
Name[fr]=Panorama
Name[ga]=Panorama
Name[gl]=Panorama
Name[hu]=Panoráma
Name[is]=Panorama
Name[it]=Panorama
Name[km]=Panorama
Name[nb]=Panorama
Name[nl]=Panorama
Name[pl]=Panorama
Name[pt]=Panorama
Name[pt_BR]=Panorama
Name[sk]=Panoráma
Name[sl]=Panorama
Name[sv]=Panorama
Name[tr]=Panorama
Name[ug]=Panorama
Name[uk]=Панорама
Name[x-test]=xxPanoramaxx
Name[zh_CN]=Panorama
Name[zh_TW]=Panorama
Comment=A tool to assemble images as a panorama
Comment[bg]=Инструмент за свързване на снимки в панорама
Comment[bs]=Alat za sklapanje slika kao panorama
Comment[ca]=Una eina per muntar imatges en un panorama
Comment[ca@valencia]=Una eina per muntar imatges en un panorama
Comment[cs]=Nástroj pro sestavování obrázku do panorama
Comment[da]=Et værktøj til at samle billeder som et panorama
Comment[de]=Ein Werkzeug, um Bilder mit einem Panorama zusammenzufügen.
Comment[el]=Εργαλείο τοποθέτησης εικόνων για τη δημιουργία πανοράματος
Comment[en_GB]=A tool to assemble images as a panorama
Comment[es]=Una herramienta para ensamblar imágenes como panorama
Comment[et]=Tööriist piltide koondamiseks panoraamina
Comment[fr]=Outil d'assemblage d'images en un panorama
Comment[ga]=Uirlis a cheanglaíonn íomhánna le chéile mar lánléargais
Comment[gl]=Unha ferramenta para encaixar imaxes nun panorama
Comment[hu]=Egy eszköz képek összerakására panorámaként
Comment[is]=Verkfæri til að sauma margar myndir saman í eina víðmynd
Comment[it]=Uno strumento per assemblare immagini come un panorama
Comment[km]=ឧបករណ៍​ត្រូវ​ផ្ដុំ​រូបភាព​ជា​ panorama
Comment[nb]=Et verktøy for å sette sammen bilder som et panorama
Comment[nl]=Een hulpmiddel om afbeeldingen samen te voegen tot een panorama
Comment[pl]=Narzędzie do składania obrazów jako panoramy
Comment[pt]=Uma ferramenta para juntar imagens como um panorama
Comment[pt_BR]=Uma ferramenta para montar imagens panorâmicas
Comment[sk]=Nástroj na zloženie obrázkov ako panoráma
Comment[sl]=Orodje za zlivanje slik v panoramsko sliko
Comment[sv]=Ett verktyg för att sammanfoga bilder till ett panorama
Comment[tr]=Resimleri bir panorama olarak birleştirmek için bir araç
Comment[ug]=سۈرەتلەرنى پاناراما قىلىدىغان قورال
Comment[uk]=Інструмент для створення панорамних зображень на основі окремих знімків
Comment[x-test]=xxA tool to assemble images as a panoramaxx
Comment[zh_TW]=將影像組成全景的工具
Icon=kipi-panorama
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_panorama
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Benjamin Girault, benjamin dot girault at gmail dot com

==> digikam-4.6.0.tar.bz2: digikam-4.6.0/extra/kipi-plugins/panorama/plugin/kipiplugin_panorama.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Panorama
Name=Panorama
Name[bg]=Панорама
Name[bs]=Panorama
Name[ca]=Panorama
Name[ca@valencia]=Panorama
Name[cs]=Panorama
Name[da]=Panorama
Name[de]=Panorama
Name[el]=Πανόραμα
Name[en_GB]=Panorama
Name[es]=Panorama
Name[et]=Panoraam
Name[fi]=Panoraama
Name[fr]=Panorama
Name[ga]=Panorama
Name[gl]=Panorama
Name[hu]=Panoráma
Name[is]=Panorama
Name[it]=Panorama
Name[km]=Panorama
Name[nb]=Panorama
Name[nl]=Panorama
Name[pl]=Panorama
Name[pt]=Panorama
Name[pt_BR]=Panorama
Name[sk]=Panoráma
Name[sl]=Panorama
Name[sv]=Panorama
Name[tr]=Panorama
Name[ug]=Panorama
Name[uk]=Панорама
Name[x-test]=xxPanoramaxx
Name[zh_CN]=Panorama
Name[zh_TW]=Panorama
Comment=A tool to assemble images as a panorama
Comment[bg]=Инструмент за свързване на снимки в панорама
Comment[bs]=Alat za sklapanje slika kao panorama
Comment[ca]=Una eina per muntar imatges en un panorama
Comment[ca@valencia]=Una eina per muntar imatges en un panorama
Comment[cs]=Nástroj pro sestavování obrázku do panorama
Comment[da]=Et værktøj til at samle billeder som et panorama
Comment[de]=Ein Werkzeug, um Bilder mit einem Panorama zusammenzufügen.
Comment[el]=Εργαλείο τοποθέτησης εικόνων για τη δημιουργία πανοράματος
Comment[en_GB]=A tool to assemble images as a panorama
Comment[es]=Una herramienta para ensamblar imágenes como panorama
Comment[et]=Tööriist piltide koondamiseks panoraamina
Comment[fi]=Kuvien yhdistäminen panoraamaksi
Comment[fr]=Outil d'assemblage d'images en un panorama
Comment[ga]=Uirlis a cheanglaíonn íomhánna le chéile mar lánléargais
Comment[gl]=Unha ferramenta para encaixar imaxes nun panorama
Comment[hu]=Egy eszköz képek összerakására panorámaként
Comment[is]=Verkfæri til að sauma margar myndir saman í eina víðmynd
Comment[it]=Uno strumento per assemblare immagini come un panorama
Comment[km]=ឧបករណ៍​ត្រូវ​ផ្ដុំ​រូបភាព​ជា​ panorama
Comment[nb]=Et verktøy for å sette sammen bilder som et panorama
Comment[nl]=Een hulpmiddel om afbeeldingen samen te voegen tot een panorama
Comment[pl]=Narzędzie do składania obrazów jako panoramy
Comment[pt]=Uma ferramenta para juntar imagens como um panorama
Comment[pt_BR]=Ferramenta para montar imagens panorâmicas
Comment[sk]=Nástroj na zloženie obrázkov ako panoráma
Comment[sl]=Orodje za zlivanje slik v panoramsko sliko
Comment[sv]=Ett verktyg för att sammanfoga bilder till ett panorama
Comment[tr]=Resimleri bir panorama olarak birleştirmek için bir araç
Comment[ug]=سۈرەتلەرنى پاناراما قىلىدىغان قورال
Comment[uk]=Інструмент для створення панорамних зображень на основі окремих знімків
Comment[x-test]=xxA tool to assemble images as a panoramaxx
Comment[zh_TW]=將影像組成全景的工具
Icon=kipi-panorama
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_panorama
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Benjamin Girault, benjamin dot girault at gmail dot com
